deltaT property

int deltaT
getter/setter pairinherited

Defines the required clock synchronization accuracy between nodes, in milliseconds.

This value represents the maximum acceptable difference in time between two nodes for them to be considered synchronized.

Implementation

int deltaT = const Duration(seconds: 10).inMilliseconds;