messageStream property
Returns a stream of incoming messages.
This stream can be subscribed to receive notifications of incoming messages.
Implementation
Stream<Message> get messageStream => _messageController.stream;
Returns a stream of incoming messages.
This stream can be subscribed to receive notifications of incoming messages.
Stream<Message> get messageStream => _messageController.stream;