retryPeriod property
The retry period for sending messages.
This value determines the interval between retries when sending messages that require confirmation.
Implementation
Duration retryPeriod = const Duration(seconds: 1);
The retry period for sending messages.
This value determines the interval between retries when sending messages that require confirmation.
Duration retryPeriod = const Duration(seconds: 1);