routes property
The routes maintained by the router, stored as a map of PeerId to
Route.
Implementation
final Map<PeerId, Route> routes = {};
The routes maintained by the router, stored as a map of PeerId to
Route.
final Map<PeerId, Route> routes = {};