Mdns class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPeerFound → void Function({required InternetAddress address, required Uint8List peerId, int? port})
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceName → String
-
final
- serviceType → String
-
final
- timeout → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
Uint8List peerId, int port) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited