removeAllBootstraps method
void
removeAllBootstraps()
inherited
Removes all bootstrap nodes from the router.
This method removes all bootstrap nodes from the router's routing table and clears the internal list of bootstrap node addresses.
Implementation
void removeAllBootstraps() {
// Iterate through the bootstrap node addresses and remove them from the
// routing table.
for (final e in _addresses.entries) {
removePeerAddress(PeerId(value: base64Decode(e.key)));
}
// Clear the internal list of bootstrap node addresses.
_addresses.clear();
}