selfAddresses property
Returns an iterable of the self addresses of this router.
These addresses represent the network endpoints where this router is listening for incoming messages.
Implementation
Iterable<FullAddress> get selfAddresses =>
transports.map((t) => t.bindAddress);